==> familia_0.1.tar.gz: familia/src/file/boundary.cpp <==
/****************************************************************************
 *  Familia Lignum - Genealogical program                                   *
 *  Copyright (C) 2011-2012 Rafał Długołęcki <rafal@dlugolecki.net.pl>      *
 *                                                                          *
 *  This program is free software; you can redistribute it and/or modify    *
 *  it under the terms of the GNU General Public License as published by    *
 *  the Free Software Foundation; version 2 of the License.                 *
 *                                                                          *
 *  This program is distributed in the hope that it will be useful,         *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of          *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
 *  GNU General Public License for more details.                            *
 *                                                                          *
 *  You should have received a copy of the GNU General Public License along *
 *  with this program; if not, write to the Free Software Foundation, Inc., *
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.             *
 *                                                                          *
 ****************************************************************************/

#include <sstream>
#include <vector>
#include "boundary.h"

using namespace std;

Boundary::_Myt& Boundary::parse(_String str, char delim) {
  istringstream ss(str);
  vector<int> fields;
  string field;
 
  while(getline(ss, field, delim)) {
    istringstream s(field);
    int i = 0;
    s >> i;
    fields.push_back(i);
  }
  set_x(fields[0]);
  set_y(fields[1]);
  set_width(fields[2] - fields[0]);
  set_height(fields[3] - fields[1]);

  return (*this);
}

==> familia_0.1.2.tar.gz: familia/src/file/boundary.cpp <==
/****************************************************************************
 *  Familia Lignum - Genealogical program                                   *
 *  Copyright (C) 2011-2012 Rafał Długołęcki <rafal@dlugolecki.net.pl>      *
 *                                                                          *
 *  This program is free software; you can redistribute it and/or modify    *
 *  it under the terms of the GNU General Public License as published by    *
 *  the Free Software Foundation; version 2 of the License.                 *
 *                                                                          *
 *  This program is distributed in the hope that it will be useful,         *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of          *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
 *  GNU General Public License for more details.                            *
 *                                                                          *
 *  You should have received a copy of the GNU General Public License along *
 *  with this program; if not, write to the Free Software Foundation, Inc., *
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.             *
 *                                                                          *
 ****************************************************************************/

#include <sstream>
#include <vector>
#include "boundary.h"

using namespace std;

Boundary::_Myt& Boundary::parse(String str, char delim) {
  istringstream ss(str);
  vector<int> fields;
  string field;
 
  while(getline(ss, field, delim)) {
    istringstream s(field);
    int i = 0;
    s >> i;
    fields.push_back(i);
  }
  set_x(fields[0]);
  set_y(fields[1]);
  set_width(fields[2] - fields[0]);
  set_height(fields[3] - fields[1]);

  return (*this);
}
